import React from 'react';
import { Field, reduxForm } from 'redux-form';


const ikons = {
    'Email': (<span className="icon is-small is-left"><i className="fa fa-envelope"></i></span>),
    'Password': (<span className="icon is-small is-left"><i className="fa fa-key"></i></span>),
};

const renderField = ({ input,
    label,
    type,
    meta: {
    touched, error, warning }
 }) =>
    <div className="field">
        <label className="label">{label}</label>
        <div className="control has-icons-left has-icons-right">
            <input {...input} className="input" type={type} placeholder={label} />
            {ikons[label]}
        </div>
        {
            touched && ((error && <p className="help is-danger">{error}</p>) || (warning && <p className="help is-danger">{warning}</p>))
        }

    </div>


let LoginForm = (props) => {
    //buradaki error serverdan gelen için
    const { error, handleSubmit, pristine, reset, submitting } = props;
    return (
        <form onSubmit={handleSubmit} >

            <Field name='email' type='email' component={renderField} label='Email' />
            <Field name='password' type='password' component={renderField} label='Password' />
            {error &&
                <strong>
                    {error}
                </strong>}
            <div className="field">
                <div className="control">
                    <label className="checkbox">
                        <input type="checkbox" />
                        I agree to the <a href="#">terms and conditions</a>
                    </label>
                </div>
            </div>
            <div className="field has-text-centered">
                <button type='submit' class="button is-primary is-large">
                    <span className="icon">
                        <i className="fa fa-key"></i>
                    </span>
                    <span>Submit</span>
                </button>
            </div>

        </form>
    )
}


LoginForm = reduxForm({
    form: 'LoginForm',
})(LoginForm);

export default LoginForm;